/* 
   This file is public domain.

   The data is a matter of public record, and comes from
   http://unstats.un.org/   
 */


SET search_path TO sqltutor;

INSERT INTO national_capitals (country, city) VALUES ('AFG', 'Kabul');
INSERT INTO national_capitals (country, city) VALUES ('ALA', 'Mariehamn');
INSERT INTO national_capitals (country, city) VALUES ('ALB', 'Tirana');
INSERT INTO national_capitals (country, city) VALUES ('DZA', 'Algiers');
INSERT INTO national_capitals (country, city) VALUES ('ASM', 'Pago Pago');
INSERT INTO national_capitals (country, city) VALUES ('AND', 'Andorra la Vella');
INSERT INTO national_capitals (country, city) VALUES ('AGO', 'Luanda');
INSERT INTO national_capitals (country, city) VALUES ('AIA', 'The Valley');
INSERT INTO national_capitals (country, city) VALUES ('ATG', 'St. John''s');
INSERT INTO national_capitals (country, city) VALUES ('ARG', 'Buenos Aires');
INSERT INTO national_capitals (country, city) VALUES ('ARM', 'Yerevan');
INSERT INTO national_capitals (country, city) VALUES ('ABW', 'Oranjestad');
INSERT INTO national_capitals (country, city) VALUES ('AUS', 'Canberra');
INSERT INTO national_capitals (country, city) VALUES ('AUT', 'Vienna');
INSERT INTO national_capitals (country, city) VALUES ('AZE', 'Baku');
INSERT INTO national_capitals (country, city) VALUES ('BHS', 'Nassau');
INSERT INTO national_capitals (country, city) VALUES ('BHR', 'Manama');
INSERT INTO national_capitals (country, city) VALUES ('BGD', 'Dhaka');
INSERT INTO national_capitals (country, city) VALUES ('BRB', 'Bridgetown');
INSERT INTO national_capitals (country, city) VALUES ('BLR', 'Minsk');
INSERT INTO national_capitals (country, city) VALUES ('BEL', 'Brussels');
INSERT INTO national_capitals (country, city) VALUES ('BLZ', 'Belmopan');
INSERT INTO national_capitals (country, city) VALUES ('BEN', 'Porto-Novo');
INSERT INTO national_capitals (country, city) VALUES ('BMU', 'Hamilton');
INSERT INTO national_capitals (country, city) VALUES ('BTN', 'Thimphu');
INSERT INTO national_capitals (country, city) VALUES ('BOL', 'Sucre');
INSERT INTO national_capitals (country, city) VALUES ('BIH', 'Sarajevo');
INSERT INTO national_capitals (country, city) VALUES ('BWA', 'Gaborone');
INSERT INTO national_capitals (country, city) VALUES ('BRA', 'Brasília');
INSERT INTO national_capitals (country, city) VALUES ('IOT', 'Diego Garcia');
INSERT INTO national_capitals (country, city) VALUES ('BRN', 'Bandar Seri Begawan');
INSERT INTO national_capitals (country, city) VALUES ('BGR', 'Sofia');
INSERT INTO national_capitals (country, city) VALUES ('BFA', 'Ouagadougou');
INSERT INTO national_capitals (country, city) VALUES ('BDI', 'Bujumbura');
INSERT INTO national_capitals (country, city) VALUES ('KHM', 'Phnom Penh');
INSERT INTO national_capitals (country, city) VALUES ('CMR', 'Yaoundé');
INSERT INTO national_capitals (country, city) VALUES ('CAN', 'Ottawa');
INSERT INTO national_capitals (country, city) VALUES ('CPV', 'Praia');
INSERT INTO national_capitals (country, city) VALUES ('CYM', 'George Town');
INSERT INTO national_capitals (country, city) VALUES ('CAF', 'Bangui');
INSERT INTO national_capitals (country, city) VALUES ('TCD', 'N''Djamena');
INSERT INTO national_capitals (country, city) VALUES ('CHL', 'Santiago');
INSERT INTO national_capitals (country, city) VALUES ('CHN', 'Beijing');
INSERT INTO national_capitals (country, city) VALUES ('CXR', 'The Settlement');
INSERT INTO national_capitals (country, city) VALUES ('CCK', 'West Island');
INSERT INTO national_capitals (country, city) VALUES ('COL', 'Bogotá');
INSERT INTO national_capitals (country, city) VALUES ('COM', 'Moroni');
INSERT INTO national_capitals (country, city) VALUES ('COG', 'Brazzaville');
INSERT INTO national_capitals (country, city) VALUES ('COD', 'Kinshasa');
INSERT INTO national_capitals (country, city) VALUES ('COK', 'Avarua');
INSERT INTO national_capitals (country, city) VALUES ('CRI', 'San José');
INSERT INTO national_capitals (country, city) VALUES ('CIV', 'Yamoussoukro');
INSERT INTO national_capitals (country, city) VALUES ('HRV', 'Zagreb');
INSERT INTO national_capitals (country, city) VALUES ('CUB', 'Havana');
INSERT INTO national_capitals (country, city) VALUES ('CYP', 'Nicosia');
INSERT INTO national_capitals (country, city) VALUES ('CZE', 'Prague');
INSERT INTO national_capitals (country, city) VALUES ('DNK', 'Copenhagen');
INSERT INTO national_capitals (country, city) VALUES ('DJI', 'Djibouti');
INSERT INTO national_capitals (country, city) VALUES ('DMA', 'Roseau');
INSERT INTO national_capitals (country, city) VALUES ('DOM', 'Santo Domingo');
INSERT INTO national_capitals (country, city) VALUES ('ECU', 'Quito');
INSERT INTO national_capitals (country, city) VALUES ('EGY', 'Cairo');
INSERT INTO national_capitals (country, city) VALUES ('SLV', 'San Salvador');
INSERT INTO national_capitals (country, city) VALUES ('GNQ', 'Malabo');
INSERT INTO national_capitals (country, city) VALUES ('ERI', 'Asmara');
INSERT INTO national_capitals (country, city) VALUES ('EST', 'Tallinn');
INSERT INTO national_capitals (country, city) VALUES ('ETH', 'Addis Ababa');
INSERT INTO national_capitals (country, city) VALUES ('FLK', 'Stanley');
INSERT INTO national_capitals (country, city) VALUES ('FRO', 'Tórshavn');
INSERT INTO national_capitals (country, city) VALUES ('FJI', 'Suva');
INSERT INTO national_capitals (country, city) VALUES ('FIN', 'Helsinki');
INSERT INTO national_capitals (country, city) VALUES ('FRA', 'Paris');
INSERT INTO national_capitals (country, city) VALUES ('GUF', 'Cayenne');
INSERT INTO national_capitals (country, city) VALUES ('PYF', 'Papeete');
INSERT INTO national_capitals (country, city) VALUES ('ATF', 'Port-aux-Français');
INSERT INTO national_capitals (country, city) VALUES ('GAB', 'Libreville');
INSERT INTO national_capitals (country, city) VALUES ('GMB', 'Banjul');
INSERT INTO national_capitals (country, city) VALUES ('GEO', 'Tbilisi');
INSERT INTO national_capitals (country, city) VALUES ('DEU', 'Berlin');
INSERT INTO national_capitals (country, city) VALUES ('GHA', 'Accra');
INSERT INTO national_capitals (country, city) VALUES ('GIB', 'Gibraltar');
INSERT INTO national_capitals (country, city) VALUES ('GRC', 'Athens');
INSERT INTO national_capitals (country, city) VALUES ('GRL', 'Nuuk');
INSERT INTO national_capitals (country, city) VALUES ('GRD', 'St. George''s');
INSERT INTO national_capitals (country, city) VALUES ('GLP', 'Basse-Terre');
INSERT INTO national_capitals (country, city) VALUES ('GUM', 'Hagåtña');
INSERT INTO national_capitals (country, city) VALUES ('GTM', 'Guatemala City');
INSERT INTO national_capitals (country, city) VALUES ('GGY', 'St. Peter Port');
INSERT INTO national_capitals (country, city) VALUES ('GIN', 'Conakry');
INSERT INTO national_capitals (country, city) VALUES ('GNB', 'Bissau');
INSERT INTO national_capitals (country, city) VALUES ('GUY', 'Georgetown');
INSERT INTO national_capitals (country, city) VALUES ('HTI', 'Port-au-Prince');
INSERT INTO national_capitals (country, city) VALUES ('VAT', 'Vatican City');
INSERT INTO national_capitals (country, city) VALUES ('HND', 'Tegucigalpa');
INSERT INTO national_capitals (country, city) VALUES ('HUN', 'Budapest');
INSERT INTO national_capitals (country, city) VALUES ('ISL', 'Reykjavík');
INSERT INTO national_capitals (country, city) VALUES ('IND', 'New Delhi');
INSERT INTO national_capitals (country, city) VALUES ('IDN', 'Jakarta');
INSERT INTO national_capitals (country, city) VALUES ('IRN', 'Tehran');
INSERT INTO national_capitals (country, city) VALUES ('IRQ', 'Baghdad');
INSERT INTO national_capitals (country, city) VALUES ('IRL', 'Dublin');
INSERT INTO national_capitals (country, city) VALUES ('IMN', 'Douglas');
INSERT INTO national_capitals (country, city) VALUES ('ISR', 'Jerusalem');
INSERT INTO national_capitals (country, city) VALUES ('ITA', 'Rome');
INSERT INTO national_capitals (country, city) VALUES ('JAM', 'Kingston');
INSERT INTO national_capitals (country, city) VALUES ('JPN', 'Tokyo');
INSERT INTO national_capitals (country, city) VALUES ('JEY', 'St. Helier');
INSERT INTO national_capitals (country, city) VALUES ('JOR', 'Amman');
INSERT INTO national_capitals (country, city) VALUES ('KAZ', 'Astana');
INSERT INTO national_capitals (country, city) VALUES ('KEN', 'Nairobi');
INSERT INTO national_capitals (country, city) VALUES ('KIR', 'South Tarawa');
INSERT INTO national_capitals (country, city) VALUES ('PRK', 'Pyongyang');
INSERT INTO national_capitals (country, city) VALUES ('KOR', 'Seoul');
INSERT INTO national_capitals (country, city) VALUES ('KWT', 'Kuwait City');
INSERT INTO national_capitals (country, city) VALUES ('KGZ', 'Bishkek');
INSERT INTO national_capitals (country, city) VALUES ('LAO', 'Vientiane');
INSERT INTO national_capitals (country, city) VALUES ('LVA', 'Riga');
INSERT INTO national_capitals (country, city) VALUES ('LBN', 'Beirut');
INSERT INTO national_capitals (country, city) VALUES ('LSO', 'Maseru');
INSERT INTO national_capitals (country, city) VALUES ('LBR', 'Monrovia');
INSERT INTO national_capitals (country, city) VALUES ('LBY', 'Tripoli');
INSERT INTO national_capitals (country, city) VALUES ('LIE', 'Vaduz');
INSERT INTO national_capitals (country, city) VALUES ('LTU', 'Vilnius');
INSERT INTO national_capitals (country, city) VALUES ('LUX', 'Luxembourg City');
INSERT INTO national_capitals (country, city) VALUES ('MKD', 'Skopje');
INSERT INTO national_capitals (country, city) VALUES ('MDG', 'Antananarivo');
INSERT INTO national_capitals (country, city) VALUES ('MWI', 'Lilongwe');
INSERT INTO national_capitals (country, city) VALUES ('MYS', 'Kuala Lumpur');
INSERT INTO national_capitals (country, city) VALUES ('MDV', 'Malé');
INSERT INTO national_capitals (country, city) VALUES ('MLI', 'Bamako');
INSERT INTO national_capitals (country, city) VALUES ('MLT', 'Valletta');
INSERT INTO national_capitals (country, city) VALUES ('MHL', 'Majuro');
INSERT INTO national_capitals (country, city) VALUES ('MTQ', 'Fort-de-France');
INSERT INTO national_capitals (country, city) VALUES ('MRT', 'Nouakchott');
INSERT INTO national_capitals (country, city) VALUES ('MUS', 'Port Louis');
INSERT INTO national_capitals (country, city) VALUES ('MYT', 'Mamoudzou');
INSERT INTO national_capitals (country, city) VALUES ('MEX', 'Mexico City');
INSERT INTO national_capitals (country, city) VALUES ('FSM', 'Palikir');
INSERT INTO national_capitals (country, city) VALUES ('MDA', 'Chisinau');
INSERT INTO national_capitals (country, city) VALUES ('MCO', 'Monaco');
INSERT INTO national_capitals (country, city) VALUES ('MNG', 'Ulaanbaatar');
INSERT INTO national_capitals (country, city) VALUES ('MNE', 'Podgorica');
INSERT INTO national_capitals (country, city) VALUES ('MSR', 'Plymouth');
INSERT INTO national_capitals (country, city) VALUES ('MAR', 'Rabat');
INSERT INTO national_capitals (country, city) VALUES ('MOZ', 'Maputo');
INSERT INTO national_capitals (country, city) VALUES ('MMR', 'Naypyidaw');
INSERT INTO national_capitals (country, city) VALUES ('NAM', 'Windhoek');
INSERT INTO national_capitals (country, city) VALUES ('NRU', 'Yaren');
INSERT INTO national_capitals (country, city) VALUES ('NPL', 'Kathmandu');
INSERT INTO national_capitals (country, city) VALUES ('NLD', 'Amsterdam');
INSERT INTO national_capitals (country, city) VALUES ('ANT', 'Willemstad');
INSERT INTO national_capitals (country, city) VALUES ('NCL', 'Nouméa');
INSERT INTO national_capitals (country, city) VALUES ('NZL', 'Wellington');
INSERT INTO national_capitals (country, city) VALUES ('NIC', 'Managua');
INSERT INTO national_capitals (country, city) VALUES ('NER', 'Niamey');
INSERT INTO national_capitals (country, city) VALUES ('NGA', 'Abuja');
INSERT INTO national_capitals (country, city) VALUES ('NIU', 'Alofi');
INSERT INTO national_capitals (country, city) VALUES ('NFK', 'Kingston');
INSERT INTO national_capitals (country, city) VALUES ('MNP', 'Saipan');
INSERT INTO national_capitals (country, city) VALUES ('NOR', 'Oslo');
INSERT INTO national_capitals (country, city) VALUES ('OMN', 'Muscat');
INSERT INTO national_capitals (country, city) VALUES ('PAK', 'Islamabad');
INSERT INTO national_capitals (country, city) VALUES ('PLW', 'Melekeok');
INSERT INTO national_capitals (country, city) VALUES ('PAN', 'Panama City');
INSERT INTO national_capitals (country, city) VALUES ('PNG', 'Port Moresby');
INSERT INTO national_capitals (country, city) VALUES ('PRY', 'Asunción');
INSERT INTO national_capitals (country, city) VALUES ('PER', 'Lima');
INSERT INTO national_capitals (country, city) VALUES ('PHL', 'Manila');
INSERT INTO national_capitals (country, city) VALUES ('PCN', 'Adamstown');
INSERT INTO national_capitals (country, city) VALUES ('POL', 'Warsaw');
INSERT INTO national_capitals (country, city) VALUES ('PRT', 'Lisbon');
INSERT INTO national_capitals (country, city) VALUES ('PRI', 'San Juan');
INSERT INTO national_capitals (country, city) VALUES ('QAT', 'Doha');
INSERT INTO national_capitals (country, city) VALUES ('REU', 'Saint-Denis');
INSERT INTO national_capitals (country, city) VALUES ('ROU', 'Bucharest');
INSERT INTO national_capitals (country, city) VALUES ('RUS', 'Moscow');
INSERT INTO national_capitals (country, city) VALUES ('RWA', 'Kigali');
INSERT INTO national_capitals (country, city) VALUES ('BLM', 'Gustavia');
INSERT INTO national_capitals (country, city) VALUES ('SHN', 'Jamestown');
INSERT INTO national_capitals (country, city) VALUES ('KNA', 'Basseterre');
INSERT INTO national_capitals (country, city) VALUES ('LCA', 'Castries');
INSERT INTO national_capitals (country, city) VALUES ('MAF', 'Marigot');
INSERT INTO national_capitals (country, city) VALUES ('SPM', 'St. Pierre');
INSERT INTO national_capitals (country, city) VALUES ('VCT', 'Kingstown');
INSERT INTO national_capitals (country, city) VALUES ('WSM', 'Apia');
INSERT INTO national_capitals (country, city) VALUES ('SMR', 'San Marino');
INSERT INTO national_capitals (country, city) VALUES ('STP', 'São Tomé');
INSERT INTO national_capitals (country, city) VALUES ('SAU', 'Riyadh');
INSERT INTO national_capitals (country, city) VALUES ('SEN', 'Dakar');
INSERT INTO national_capitals (country, city) VALUES ('SRB', 'Belgrade');
INSERT INTO national_capitals (country, city) VALUES ('SYC', 'Victoria');
INSERT INTO national_capitals (country, city) VALUES ('SLE', 'Freetown');
INSERT INTO national_capitals (country, city) VALUES ('SGP', 'Singapore');
INSERT INTO national_capitals (country, city) VALUES ('SVK', 'Bratislava');
INSERT INTO national_capitals (country, city) VALUES ('SVN', 'Ljubljana');
INSERT INTO national_capitals (country, city) VALUES ('SLB', 'Honiara');
INSERT INTO national_capitals (country, city) VALUES ('SOM', 'Mogadishu');
INSERT INTO national_capitals (country, city) VALUES ('ZAF', 'Pretoria');
INSERT INTO national_capitals (country, city) VALUES ('SGS', 'Grytviken');
INSERT INTO national_capitals (country, city) VALUES ('ESP', 'Madrid');
INSERT INTO national_capitals (country, city) VALUES ('LKA', 'Sri Jayawardenepura');
INSERT INTO national_capitals (country, city) VALUES ('SDN', 'Khartoum');
INSERT INTO national_capitals (country, city) VALUES ('SUR', 'Paramaribo');
INSERT INTO national_capitals (country, city) VALUES ('SWZ', 'Lobamba');
INSERT INTO national_capitals (country, city) VALUES ('SWE', 'Stockholm');
INSERT INTO national_capitals (country, city) VALUES ('CHE', 'Bern');
INSERT INTO national_capitals (country, city) VALUES ('SYR', 'Damascus');
INSERT INTO national_capitals (country, city) VALUES ('TWN', 'Taipei');
INSERT INTO national_capitals (country, city) VALUES ('TJK', 'Dushanbe');
INSERT INTO national_capitals (country, city) VALUES ('TZA', 'Dodoma');
INSERT INTO national_capitals (country, city) VALUES ('THA', 'Bangkok');
INSERT INTO national_capitals (country, city) VALUES ('TLS', 'Dili');
INSERT INTO national_capitals (country, city) VALUES ('TGO', 'Lomé');
INSERT INTO national_capitals (country, city) VALUES ('TON', 'Nukuʻalofa');
INSERT INTO national_capitals (country, city) VALUES ('TTO', 'Port of Spain');
INSERT INTO national_capitals (country, city) VALUES ('TUN', 'Tunis');
INSERT INTO national_capitals (country, city) VALUES ('TUR', 'Ankara');
INSERT INTO national_capitals (country, city) VALUES ('TKM', 'Ashgabat');
INSERT INTO national_capitals (country, city) VALUES ('TCA', 'Cockburn Town');
INSERT INTO national_capitals (country, city) VALUES ('TUV', 'Funafuti');
INSERT INTO national_capitals (country, city) VALUES ('UGA', 'Kampala');
INSERT INTO national_capitals (country, city) VALUES ('UKR', 'Kiev');
INSERT INTO national_capitals (country, city) VALUES ('ARE', 'Abu Dhabi');
INSERT INTO national_capitals (country, city) VALUES ('GBR', 'London');
INSERT INTO national_capitals (country, city) VALUES ('USA', 'Washington, D.C.');
INSERT INTO national_capitals (country, city) VALUES ('URY', 'Montevideo');
INSERT INTO national_capitals (country, city) VALUES ('UZB', 'Tashkent');
INSERT INTO national_capitals (country, city) VALUES ('VUT', 'Port Vila');
INSERT INTO national_capitals (country, city) VALUES ('VEN', 'Caracas');
INSERT INTO national_capitals (country, city) VALUES ('VNM', 'Hanoi');
INSERT INTO national_capitals (country, city) VALUES ('VGB', 'Road Town');
INSERT INTO national_capitals (country, city) VALUES ('VIR', 'Charlotte Amalie');
INSERT INTO national_capitals (country, city) VALUES ('WLF', 'Mata-Utu');
INSERT INTO national_capitals (country, city) VALUES ('ESH', 'Laâyoune');
INSERT INTO national_capitals (country, city) VALUES ('YEM', 'Sanaá');
INSERT INTO national_capitals (country, city) VALUES ('ZMB', 'Lusaka');
INSERT INTO national_capitals (country, city) VALUES ('ZWE', 'Harare');
